<?php
/**
 * Clase PagoBL
 *
 * @package    
 * @subpackage 
 * @author     PagoBL
 * @version    SVN: $Id: PagoBL.class.php,v 1.1 2008/02/08 21:56:44 william.taype Exp $ 
 */
class PagoBL{
    
  /**
  * 
  *
  * @param $o_PagoBean, objeto de  Pago 
  * @return Boolean
  */
  
  public function busquedaPago(PagoBean $o_PagoBean){
    
    $o_PagoDP = new PagoDP($o_PagoBean);
    if($o_PagoBean->getIdPago()){
      $a_Pago = $o_PagoDP->selectByPk();
    }else{
      $a_Pago = $o_PagoDP->select();
    }
    $suma_pago= 0;
    if(is_array($a_Pago)){
    	foreach ($a_Pago as $key => $o_Pago){
		    //Administrador en el Gri unido la Tabla Sucursal con Colaborador 
		    $o_PrestamoBean = new PrestamoBean();
		    $o_PrestamoBean->setIdPrestamo($o_Pago->getIdPrestamo());
		    $o_PrestamoBL = new PrestamoBL();
			$a_Prestamo = $o_PrestamoBL->busquedaPrestamo($o_PrestamoBean);
		    $o_Pago->setObjectPrestamo($a_Prestamo[0]);
		    $suma_pago = $o_Pago->getMontoPago() + $suma_pago ;
		    $a_temp[] = $o_Pago;
    	}
    }elseif (is_object($a_Pago)){
    	 //Administrador en el Gri unido la Tabla Sucursal con Colaborador 
	    $o_PrestamoBean = new PrestamoBean();
	    $o_PrestamoBean->setIdPrestamo($a_Pago->getIdPrestamo());
	    $o_PrestamoBL = new PrestamoBL();
		$a_Prestamo = $o_PrestamoBL->busquedaPrestamo($o_PrestamoBean);
	    $a_Pago->setObjectPrestamo($a_Prestamo[0]);
	    $a_temp[] = $a_Pago;
	     $suma_pago = $o_Pago->getMontoPago() +$suma_pago ;
    }
    return $a_temp;
  }


  
  public function insertarPago(PagoBean $o_PagoBean){
    
    $o_PagoCT = new PagoCT();
    return $o_PagoCT->guardar($o_PagoBean);
    
  }
  	public function modificarPago(PagoBean $o_PagoBean){
	  
    $o_PagoCT = new PagoCT();
    return $o_PagoCT->modificar($o_PagoBean);
	
	}
	
	
  /**
	* Función que retorna un objeto Pago o una lista de Objetos de Pago,
	* dependiendo del parametro que se le envia si este contiene o no el Id de Pago
	*
	* @param $o_PagoBean, es un objeto de  Pago
	* @return Object
	*/
	public function modificarEstadoPago(PagoBean $o_PagoBean){
	  
	
	}
	
	/*public function busquedaPagoDetalles(PagoBean $o_PagoBean){
        
    $o_Pago = $this->busquedaPago($o_PagoBean);
    
   $o_SucursalMercadoBean = new SucursalMercadoBean();
    $o_SucursalMercadoBean->setIdSucursal($o_Sucursal[0]->getIdSucursal());
    
   $o_SucursalMercadoBL = new SucursalMercadoBL();
   $a_tmpSucursalMercado = $o_SucursalMercadoBL->busquedaSucursalMercadoDetalle($o_SucursalMercadoBean);
    
    
		    
   $o_Sucursal[0]->setArraySucMercado($a_tmpSucursalMercado);
    
    return $o_Pago[0];
  
  }*/
	public function getPago(PagoBean $o_PagoBean){
    
    $o_PagoCT = new PagoCT();
    return $o_PagoCT->seleccionar($o_PagoBean);
    
  }
  
  public function eliminarPago(PagoBean $o_PagoBean){
     $o_PagoCT = new PagoCT();
    return $o_PagoCT->eliminar($o_PagoBean);
  }
  public function getCountResult(PagoBean $o_PagoBean){
    $o_PagoCT = new PagoCT();
    return $o_PagoCT->totalRegistros($o_PagoBean);
  }
  
  
}



